==> haskell-streaming-commons-0.2.1.0-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: streaming-commons
version: 0.2.1.0
id: streaming-commons-0.2.1.0-98A77q62kI8Fyxj1zEbMgD
key: streaming-commons-0.2.1.0-98A77q62kI8Fyxj1zEbMgD
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, Emanuel Borsboom
homepage: https://github.com/fpco/streaming-commons
synopsis: Common lower-level functions needed by various streaming data libraries
description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.
category: Data
abi: a085785e2c57222ffc79e5f70af9c7e6
exposed: True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel
hidden-modules: Data.Text.Internal.Unsafe.Char
                Data.Text.Internal.Unsafe.Shift Data.Text.Internal.Encoding.Utf8
                Data.Text.Internal.Encoding.Utf16 Data.Text.Internal.Encoding.Utf32
import-dirs: /usr/lib/ghc-8.6.3/site-local/streaming-commons-0.2.1.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/streaming-commons-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/streaming-commons-0.2.1.0
hs-libraries: HSstreaming-commons-0.2.1.0-98A77q62kI8Fyxj1zEbMgD
depends:
    array-0.5.3.0 async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 directory-1.3.3.0
    network-2.7.0.2-l7ToO0nOP7DBjiP2hy2PR process-1.6.3.0
    random-1.1-3ypV4EIycgb35PKjTYYr5q stm-2.5.0.0 text-1.2.3.1
    transformers-0.5.5.0 unix-2.7.2.2 zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock
haddock-html: /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-streaming-commons-0.2.1.0-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: streaming-commons
version: 0.2.1.0
id: streaming-commons-0.2.1.0-15W45nbTYkRK5EyyGV2Ti
key: streaming-commons-0.2.1.0-15W45nbTYkRK5EyyGV2Ti
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, Emanuel Borsboom
homepage: https://github.com/fpco/streaming-commons
synopsis: Common lower-level functions needed by various streaming data libraries
description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.
category: Data
abi: cf9f411c4a7fc2fc7e093e984409f890
exposed: True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel
hidden-modules: Data.Text.Internal.Unsafe.Char
                Data.Text.Internal.Unsafe.Shift Data.Text.Internal.Encoding.Utf8
                Data.Text.Internal.Encoding.Utf16 Data.Text.Internal.Encoding.Utf32
import-dirs: /usr/lib/ghc-8.6.3/site-local/streaming-commons-0.2.1.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/streaming-commons-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/streaming-commons-0.2.1.0
hs-libraries: HSstreaming-commons-0.2.1.0-15W45nbTYkRK5EyyGV2Ti
depends:
    array-0.5.3.0 async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 directory-1.3.3.0
    network-2.7.0.2-LBw9vnb0Msk5Ad9gKMihTx process-1.6.3.0
    random-1.1-3ypV4EIycgb35PKjTYYr5q stm-2.5.0.0 text-1.2.3.1
    transformers-0.5.5.0 unix-2.7.2.2 zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock
haddock-html: /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
